%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Characteristic Length
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% updated to find the characteristic length of Li's manipulator.
%
% This program prepares and run the minimization procedure inorder to obtain
% optimum condition number of Fanuc ArcMate robot.
%
% Nelder-Mead Simplex method for unconstrained optimization is used.
% Update Jan 01, 2004.
%
%
%%%%%% fminsearch description %%%%%%
%
% FMINSEARCH Multidimensional unconstrained nonlinear minimization (Nelder-Mead).
%
%   [X,FVAL,EXITFLAG,OUTPUT] = FMINSEARCH(FUN,X0,OPTIONS) starts at X0 and finds a local 
%   minimizer X of the function FUN. FUN accepts input X and returns a scalar function value 
%   F evaluated at X. X0 can be a scalar, vector or matrix. The 'Options' minimizes with the 
%   default optimization parameters replaced by values in the structure OPTIONS, created
%   with the OPTIMSET function.  See OPTIMSET for details.  FMINSEARCH uses
%   these options: Display, TolX, TolFun, MaxFunEvals, and MaxIter. FVAL returns the value 
%   of the objective function, described in FUN, at X. EXITFLAGE returns a string that 
%   describes the exit condition of FMINSEARCH.  
%   If EXITFLAG is:
%     1 then FMINSEARCH converged with a solution X.
%     0 then the maximum number of iterations was reached.returns a structure
%   OUTPUT with the number of iterations taken in OUTPUT.iterations.
%
%   FMINSEARCH uses the Nelder-Mead simplex (direct search) method.
%
%   Reference: Jeffrey C. Lagarias, James A. Reeds, Margaret H. Wright,
%   Paul E. Wright, "Convergence Properties of the Nelder-Mead Simplex
%   Method in Low Dimensions", SIAM Journal of Optimization, 9(1): 
%   p.112-147, 1998.
%
% Default values of options
% defaultopt = struct('Display','notify','MaxIter','200*numberOfVariables',...
%   'MaxFunEvals','200*numberOfVariables','TolX',1e-4,'TolFun',1e-4);
%
%% fminsearch description END %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% 1. Assign vector x_v, the initial guess of 5 parameters i.e. [overlineM theta2..theta6]
% 2. b(1), theta(1) and alpha(6) are not included
% 3. An initial guess close to the results reported in FRMS Angeles 2002 was taken.

function [condiJ,l,x] = fun(tutu)

% default options are
% TolX=1e-4, TolFun=1e-4, MaxFunEvals=5000, MaxIter=5000 (for 25 variables)
%
% defining options in case the above defaults are not suitable
options = optimset('TolX',1e-4,'TolFun',1e-4,'MaxFunEvals',10000,'MaxIter',10000);

hfigM = findobj('Tag','INPUT');
data = getappdata(hfigM, 'DATA');

x_v = [data.xv1 data.xv2 data.xv3 data.xv4 data.xv5 data.xv6];

setappdata(findobj('Tag','INPUT'), 'DATA', data);


% Note: the angle is in degrees. Angle values are converted to radians in the objective function
%calling the minimization function
[x,fval,exitflag,output] = fminsearch('objfun',x_v,options);

[k,J,r_v,l]=objfun(x); % We use the objective function to return the Jacobian.

condiJ = 1/6*(cond(J,'fro'));




